plone.app.event.setuphandlers — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.setuphandlers

`plone.app.event.setuphandlers.` `catalog_setup`(context)

  Setup plone.app.event’s indices in the catalog.

  Doing it here instead of in profiles/default/catalog.xml means we do not need to reindex those indexes after every reinstall.

  See these discussions for more info about index clearing with catalog.xml:
    http://plone.293351.n2.nabble.com/How-to-import-catalog-xml-without- emptying-the-indexes-td2302709.html https://mail.zope.org/pipermail/zope-cmf/2007-March/025664.html

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »